<?php

/**
 * @file
 * Admin functions for the User Access Hub module.
 */

/**
 * Settings form callback.
 *
 * @param array $form
 *   Form array.
 * @param array $form_state
 *   Form state array.
 *
 * @return array
 *   Renderable form array.
 */
function useracceshub_settings_form(array $form, array &$form_state) {
  $form = array();

  $form['useraccesshub_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable all of the User Access Hub functionality.'),
    '#default_value' => variable_get('useraccesshub_enabled', FALSE),
  );
  $form['useraccesshub_redirect'] = array(
    '#type' => 'textfield',
    '#title' => t('Redirect URL/Path'),
    '#description' => t('Where to redirect the user after a login, including a preceeding /. For example: /user.'),
    '#default_value' => variable_get('useraccesshub_redirect', '/user'),
  );

  return system_settings_form($form);
}

/**
 * Authentication form callback.
 *
 * @param array $form
 *   Form array.
 * @param array $form_state
 *   Form state array.
 *
 * @return array
 *   Renderable form array.
 */
function useracceshub_authentication_form(array $form, array &$form_state) {
  $form = array();

  $form['description'] = array(
    '#type' => 'markup',
    '#markup' => t('The following data is for informational purposes and none of these values can be modified here.'),
  );
  $form['useraccesshub_api_key'] = array(
    '#type' => 'textarea',
    '#title' => t('API Key'),
    '#description' => t('The API key is generated on module install. This API key is only used during the handshake process between the User Access Hub and this site. Once the handshake is complete the public key below is used during communication between the two. This value can be regenerated using the action button above.'),
    '#disabled' => TRUE,
    '#default_value' => variable_get('useraccesshub_api_key'),
    '#rows' => 5,
  );
  $form['useraccesshub_public_key'] = array(
    '#type' => 'textarea',
    '#title' => t('Public Key'),
    '#description' => t('The public key is set during the handshake process between the User Access Hub and this site and is used for all communication between this site and the User Access Hub.'),
    '#disabled' => TRUE,
    '#default_value' => variable_get('useraccesshub_public_key'),
    '#rows' => 10,
  );
  $form['useraccesshub_site_id'] = array(
    '#type' => 'textfield',
    '#title' => t('Site ID'),
    '#description' => t('The site ID is the unique identifier for this site in the User Access Hub and is using during communication between the and this site. This value is set during the handshake process between the two.'),
    '#disabled' => TRUE,
    '#default_value' => variable_get('useraccesshub_site_id'),
  );
  $form['useraccesshub_handshake_enabled'] = array(
    '#type' => 'checkbox',
    '#title' => t('Enable the handshake endpoint.'),
    '#description' => t('Once the handshake is done, the handshake endpoint is disabled (for security purposes). This value can be enabled with drush or by using a config override value in settings.php. Only enable if a new handshake is required.'),
    '#disabled' => TRUE,
    '#default_value' => variable_get('useraccesshub_handshake_enabled'),
  );

  $form['actions']['submit']['#access'] = FALSE;

  return $form;
}

/**
 * Roles form callback.
 *
 * @param array $form
 *   Form array.
 * @param array $form_state
 *   Form state array.
 *
 * @return array
 *   Renderable form array.
 */
function useracceshub_roles_form(array $form, array &$form_state) {
  $form = array();

  $roles = user_roles(TRUE);

  $form['role_wrapper'] = array(
    '#type' => 'fieldset',
    '#title' => t('Roles'),
  );
  $form['role_wrapper']['useraccesshub_roles'] = array(
    '#type' => 'checkboxes',
    '#title_display' => 'invisible',
    '#title' => t('Roles'),
    '#description' => t('Select which roles should have SSO login enabled from the User Access Hub. All roles not selected will still be able to login using the site login form.'),
    '#options' => $roles,
    '#default_value' => variable_get('useraccesshub_roles', array()),
  );
  $form['role_wrapper']['useraccesshub_default_role'] = array(
    '#type' => 'select',
    '#title' => t('Default Role'),
    '#description' => t('Select which role should be considered the default.'),
    '#options' => $roles,
    '#default_value' => variable_get('useraccesshub_default_role'),
  );
  $form['useraccesshub_allow_local'] = array(
    '#type' => 'checkbox',
    '#title' => t('Allow local accounts to login (for managed roles above).'),
    '#default_value' => variable_get('useraccesshub_allow_local'),
  );

  return system_settings_form($form);
}

/**
 * Generate a new API key.
 */
function useraccesshub_generate_key_action() {
  variable_set('useraccesshub_api_key', _useraccesshub_generate_key());
  drupal_set_message(t('New API key generated successfully.'));
  drupal_goto('admin/config/useraccesshub/auth');
}
